@@ -10,7 +10,7 @@ use Data::Section { installer => method_installer }, -setup;
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '2.19'; # VERSION
+our $VERSION = '2.20'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileGatherer';
@@ -41,6 +41,12 @@ has _diag_content => (
   default => '',
 );
 
+has test2_v0 => (
+  is      => 'ro',
+  isa     => 'Int',
+  default => 0,
+);
+
 sub gather_files
 {
   my($self) = @_;
@@ -73,7 +79,7 @@ sub before_build
   : dir(Dist::Zilla::MintingProfile::Author::Plicease->profile_dir)->subdir(qw( default skel xt release ));
 
   my $diag = dir($self->zilla->root)->file(qw( t 00_diag.t ));
-  my $content = $source->parent->parent->file('t', '00_diag.t')->absolute->slurp;
+  my $content = $source->parent->parent->file('t', $self->test2_v0 ? '00_xdiag.t' : '00_diag.t' )->absolute->slurp;
   $content =~ s{## PREAMBLE ##}{join "\n", map { s/^\| //; $_ } @{ $self->diag_preamble }}e;
   $self->_diag_content($content);
 }
@@ -178,7 +184,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 2.19
+version 2.20
 
 =head1 SYNOPSIS
 
